vfbLib.typing
=============

.. automodule:: vfbLib.typing
  
   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      AnchorDict
      BBoxDict
      BackgroundImageDict
      BitmapDataDict
      Component
      CustomCmap
      EntryDict
      FeatureDict
      FeaturesDict
      GaspRangeDict
      GdefDict
      GlyphBitmapDict
      GlyphData
      GuideDict
      GuidePropertiesDict
      GuidePropertyDict
      HintDict
      Instruction
      LinkDict
      MMAnchorDict
      MMGuidesDict
      MMHintsDict
      MMNode
      MaskData
      PSInfoDict
      PrimaryInstanceDict
      TTCommandDict
      TTStemDict
      TTStemsDict
      TTZoneDict
      TTZonesDict
      VfbDict
   
   

   
   
   



